<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:ms="urn:schemas-microsoft-com:xslt"
xmlns:vb="urn:the-xml-files:xslt-vb"
xmlns:js="urn:the-xml-files:xslt-js"
version="1.0">
<xsl:output method="text"/>
<xsl:include href="../Reports/Common.inc"/>
<xsl:include href="../Reports/LocaleIndependent.inc"/>
<xsl:include href="../Reports/PlanEntryProcessing.inc"/>
<xsl:include href="../Reports/Subprojects.inc"/>
<xsl:param name="Filter"/>
<xsl:param name="TransparentCategories"/>
<xsl:param name="ProjectPath"/>
<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
<xsl:template match="/">Category,Name,Priority,Estimation (hours),Spent (hours),Original estimation (hours),Status,Deadline
<xsl:for-each select="ROOT/CATEGORY">
	<xsl:apply-templates select="."/>
</xsl:for-each>
</xsl:template>

<xsl:template name="ProcessCategory">
	<xsl:if test="./TASK">
		<xsl:variable name="categoryName">$\<xsl:value-of 
		select="$ProjectPath"/>\<xsl:value-of 
		select="vb:GetParentNamesSep(., '\')"/><xsl:value-of 
		select="@NAME"/></xsl:variable>
		<xsl:for-each select="./TASK">
			<xsl:sort select="@STATUS" order="descending"/>
			<xsl:sort select="@IMPORTANCE"/>
			<xsl:sort select="@DEADLINE"/>
			<xsl:sort select="@NAME"/>
			<xsl:choose>
			<xsl:when test="$Filter = 1">
				<xsl:if test="@STATUS != 2">
					<xsl:call-template name="InitDescendants">
					<xsl:with-param name="categoryName" select="$categoryName"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Filter = 2">
				<xsl:if test="@STATUS = 0">
					<xsl:call-template name="InitDescendants">
					<xsl:with-param name="categoryName" select="$categoryName"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Filter = 3">
				<xsl:if test="@STATUS = 1">
					<xsl:call-template name="InitDescendants">
					<xsl:with-param name="categoryName" select="$categoryName"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$Filter = 4">
				<xsl:if test="@STATUS = 2">
					<xsl:call-template name="InitDescendants">
					<xsl:with-param name="categoryName" select="$categoryName"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="InitDescendants">
				<xsl:with-param name="categoryName" select="$categoryName"/>
				</xsl:call-template>
			</xsl:otherwise>
			</xsl:choose>
		</xsl:for-each>
	</xsl:if>
	<xsl:if test="$TransparentCategories != 0">
	<xsl:if test="./CATEGORY">
	<xsl:if test=".//TASK">
		<xsl:for-each select="./CATEGORY">
			<xsl:sort select="@NAME"/>
			<xsl:apply-templates select="."/>
		</xsl:for-each>
	</xsl:if>
	</xsl:if>
	</xsl:if>
</xsl:template>

<xsl:template name="InitDescendants">
	<xsl:param name="categoryName"/>
	<xsl:value-of 
		select="$categoryName"/>,<xsl:apply-templates 
		select="."/>
</xsl:template>

<xsl:template match="CATEGORY">
	<xsl:call-template name="ProcessCategory"/>	
</xsl:template>

<xsl:template name="ProcessTask">
	<xsl:variable name="id" 
	select="@ID"/><xsl:variable name="planEntriesList" 
	select="key('task_key', $id)"/><xsl:variable name="workingHours" 
	select="vb:CalculateHours($planEntriesList)"/>&quot;<xsl:value-of 
	select="@NAME"/>&quot;,&quot;<xsl:value-of 
	select="vb:GetImportanceString(@IMPORTANCE)"/>&quot;,&quot;<xsl:value-of 
	select="vb:FormatNumberEx(js:ToDbl(string(@ESTIMATION)))"/>&quot;,&quot;<xsl:value-of 
	select="$workingHours"/>&quot;,&quot;<xsl:if 
	test="@ORIGINALESTIMATION &gt; -1"><xsl:value-of 
	select="vb:FormatNumberEx(js:ToDbl(string(@ORIGINALESTIMATION)))"/></xsl:if>&quot;,&quot;<xsl:value-of 
	select="vb:GetStatusString(@STATUS)"/>&quot;,&quot;<xsl:value-of 
	select="vb:FormatDate(string(@DEADLINE))"/>&quot;
</xsl:template>

<xsl:template match="TASK">
	<xsl:call-template name="ProcessTask"/>	
</xsl:template>

</xsl:stylesheet>