<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
<xsl:output method="html"/>
<xsl:param name="ReportingPeriodStart"/>
<xsl:param name="ReportingPeriodEnd"/>
<xsl:include href="LocaleIndependent.inc"/>
<xsl:include href="Common.inc"/>
<xsl:include href="WeekProcessing.inc"/>
<xsl:include href="PlanEntryProcessing.inc"/>
<xsl:include href="HolidaysProcessing.inc"/>
<xsl:include href="Intending.inc"/>
<xsl:include href="ReportCSS.inc"/>
<xsl:key name="task_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>

<xsl:template match="/">
	<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
	<xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
	<HTML>
	<HEAD>
	<TITLE>{Report}: {COBStatusReport} (<xsl:value-of select="vb:FormatThisPeriod()"/>)</TITLE>
	<META NAME="Report" CONTENT="{COBStatusReport}"/>
	<STYLE ID="ReportStyle">
	<xsl:value-of select="$css"/>
	</STYLE>
	</HEAD>
	<BODY>

<h2 align="center">{COBStatusReport}</h2>

<xsl:for-each select="//PROPERTIES">
<table border="0" cellpadding="2" cellspacing="0">
	<tr>
	<td class="righttitle">{Employee}: </td>
	<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
	</tr>
	<tr>
	<td class="righttitle">{ReportingPeriod}: </td>
	<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
	</tr>
</table>
</xsl:for-each>

		<xsl:variable name="currentContext" select="/"/>
		<xsl:value-of select="vb:ResetStart()"/>
		<xsl:for-each select="ms:node-set($weekDaysList)/IT">
			<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
				<xsl:if test="not(vb:IsHoliday(vb:GetDaysIteratorString()))">
				<xsl:for-each select="ms:node-set($currentContext)">
					<xsl:variable name="curDate" select="vb:GetDaysIteratorString()"/>
					<P ALIGN="center">
					<b>
					<xsl:value-of select="vb:ToAbbrWeekDay(vb:GetDaysIteratorString())"/> - <xsl:value-of select="vb:GetDaysIteratorString()"/>
					</b>
					</P>
					
					<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
					<THEAD style="display: table-header-group">
					<TR>
						<TD class="leftHeadCell">{Task}</TD>
						<TD class="headCell">{Description}</TD>
						<TD class="headCell">{Status}</TD>
						<TD class="headCell">{EstimatedTimeUsed}</TD>
						<TD class="headCell">{Deadline}</TD>
					</TR>
					</THEAD>
					<TBODY>
					<xsl:for-each select="ROOT/CATEGORY">
						<xsl:sort select="@NAME"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
					</TBODY>
					</TABLE>
				</xsl:for-each>
				</xsl:if>
				<xsl:value-of select="vb:MoveNextDay()"/>
			</xsl:if>
		</xsl:for-each>
		
		<BR/>
<table border="0" cellpadding="2" cellspacing="0">
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell">{ManagerSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
</table>
				
			</BODY>
		</HTML>
	</xsl:template>
	<xsl:template match="CATEGORY">
		<xsl:variable name="taskid" select=".//TASK/@ID"/>
		<xsl:variable name="planEntriesListCat" select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY[@TASKID=$taskid]"/>
		<xsl:variable name="nPlanEntriesCat" select="count($planEntriesListCat)"/>
		<xsl:if test="$nPlanEntriesCat&gt;0">
			<TR>
				<TD class="categoryCell">
					<xsl:attribute name="COLSPAN">5</xsl:attribute>
					<xsl:value-of select="vb:GetIntend(.)"/><xsl:value-of select="@NAME"/>
				</TD>
			</TR>
			<xsl:if test="./TASK">
				<xsl:for-each select="./TASK">
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:if>
			<xsl:if test="./CATEGORY">
				<xsl:for-each select="./CATEGORY">
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="TASK">
		<xsl:variable name="id" select="@ID"/>
		<xsl:variable name="planEntriesList" select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY[@TASKID=$id]"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>
		<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
		<xsl:if test="$nPlanEntries&gt;0">
			<TR>
				<TD class="taskCell"><xsl:value-of select="vb:GetRecentIntend()"/><xsl:value-of select="@NAME"/></TD>
				<TD class="taskDescription">
					<xsl:for-each select="ms:node-set($planEntriesList)"><xsl:value-of select="vb:RestrictLength(string(DESCRIPTION), 110)"/>&#160;</xsl:for-each>
				</TD>
				<TD class="freeTableCell"><xsl:value-of select="vb:GetStatusString(@STATUS)"/></TD>
				<TD class="freeTableCell"><xsl:value-of select="vb:CalculateEstTimeUsed($workingHours, js:ToDbl(number(@ESTIMATION)))"/>%</TD>
				<TD class="freeTableCell"><xsl:value-of select="vb:FormatDate(string(@DEADLINE))"/></TD>
			</TR>
		</xsl:if>
	</xsl:template>
	<xsl:template name="TaskHours">
		<xsl:param name="currentContext"/>
		<xsl:param name="id"/>
		<xsl:value-of select="vb:ResetStart()"/>
		<xsl:for-each select="ms:node-set($weekDaysList)/IT">
			<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
				<xsl:for-each select="ms:node-set($currentContext)">
					<xsl:variable name="daysList" select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY[@TASKID=$id]"/>
					<xsl:variable name="dayTaskHours" select="vb:CalculateHoursWONuls($daysList)"/>
					<TD class="tableCell"><xsl:call-template name="HolidayColoring">
							<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
							<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
						</xsl:call-template>
						<xsl:value-of select="$dayTaskHours"/>
					</TD>
				</xsl:for-each>
			</xsl:if>
			<xsl:value-of select="vb:MoveNextDay()"/>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="DailyTotals">
		<xsl:param name="currentContext"/>
		<xsl:value-of select="vb:ResetStart()"/>
		<xsl:for-each select="ms:node-set($weekDaysList)/IT">
			<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
				<xsl:for-each select="ms:node-set($currentContext)">
					<xsl:variable name="daysList" select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY"/>
					<xsl:variable name="dayTaskHours" select="vb:CalculateHoursWONuls($daysList)"/>
					<TD class="totalCell"><xsl:value-of select="$dayTaskHours"/></TD>
				</xsl:for-each>
				<xsl:value-of select="vb:MoveNextDay()"/>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	<xsl:template name="HolidayColoring">
		<xsl:param name="defaultColor"/>
		<xsl:param name="holidayColor"/>
		<xsl:attribute name="BGCOLOR">
			<xsl:choose>
				<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
</xsl:stylesheet>
