<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:param name="ReportingPeriodStart"/>
	<xsl:param name="ReportingPeriodEnd"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_day_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]" use="PLANENTRY/@TASKID"/>
	<xsl:template match="/">
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if>
		</xsl:variable>
		<xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>
		<HTML>
			<HEAD>
				<META NAME="Report" CONTENT="{CompletedTasksWeek}"/>
				<TITLE>{Report}: {CompletedTasksForPeriodSince} <xsl:value-of select="vb:FormatThisPeriod()"/> of project &quot;<xsl:value-of select="$projectTitle"/>&quot;</TITLE>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
			<H2>{CompletedTasksWeek}</H2>
			
			<xsl:for-each select="//PROPERTIES">
			<table border="0" cellpadding="2" cellspacing="0">
				<tr>
				<td class="righttitle">{Employee}: </td>
				<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
				</tr>
				<tr>
				<td class="righttitle">{Category}: </td>
				<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
				</tr>
				<tr>
				<td class="righttitle">{Period}: </td>
				<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
				</tr>
			</table>
			</xsl:for-each>
			
			<br/>

			<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
			<THEAD style="display: table-header-group"> 
			<TR>
			<TD class="leftHeadCell">{Name}</TD>
			<TD class="headCell">{Description}</TD>
			<TD class="headCell">{CompletedAt}</TD>
			</TR>
			</THEAD>
			<TBODY>
			<xsl:choose>
			<xsl:when test="$AffectedCategory != 0">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="vb:SetBaseIntend(vb:GetIntend(.))"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
			<xsl:for-each select="ROOT/CATEGORY">
				<xsl:value-of select="vb:SetBaseIntend('')"/>
				<xsl:apply-templates select="."/>
			</xsl:for-each>
			</xsl:otherwise>
			</xsl:choose>
			</TBODY>
			</TABLE>
			
			<BR/>
			<table border="0" cellpadding="2" cellspacing="0">
			<tr><td colspan="2">&#160; </td></tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			<tr><td colspan="2">&#160; </td></tr>
			<tr>
			<td class="signetureCell">{ManagerSignature}</td>
			<td class="signetureCell">{Date}</td>
			</tr>
			</table>
				
			</BODY>
		</HTML>
	</xsl:template>
	
	<xsl:template match="CATEGORY">
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', .//TASK[@STATUS=2]/@ID)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesDaysList)"/>
		<xsl:if test="$nPlanEntries&gt;0">

			<TR>
				<TD class="categoryCell">
					<xsl:value-of select="vb:GetIntend(.)"/>
					<xsl:value-of select="@NAME"/>
				</TD>
				<TD class="categoryDescription">
					<xsl:value-of select="vb:RestrictLength(string(DESCRIPTION), 110)"/>&#160;
				</TD>
				<TD class="categoryTotal">&#160;
				</TD>
			</TR>
			
			<xsl:if test="./TASK[@STATUS=2]">
				<xsl:for-each select="./TASK">
					<xsl:sort select="@NAME"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:if>
			<xsl:if test="./CATEGORY">
				<xsl:if test=".//TASK[@STATUS=2]">
					<xsl:for-each select="./CATEGORY">
						<xsl:sort select="@NAME"/>
						<xsl:apply-templates select="."/>
					</xsl:for-each>
				</xsl:if>
			</xsl:if>
		</xsl:if>
	</xsl:template>
	<xsl:template match="TASK">
	<xsl:if test="@STATUS=2">
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', @ID)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesDaysList)"/>
		<xsl:if test="$nPlanEntries&gt;0">
			<xsl:variable name="lastPlanEntryDate" select="vb:GetLastPlanEntryDate($planEntriesDaysList)"/>
			<TR>
			<TD class="taskCell">
				<xsl:value-of select="vb:GetRecentIntend()"/><xsl:value-of select="@NAME"/>
			</TD>
			<TD class="taskDescription">
				<xsl:value-of select="vb:RestrictLength(string(DESCRIPTION), 110)"/>&#160;
			</TD>
			<TD class="freeTableCell">
				<xsl:value-of select="vb:FormatDate($lastPlanEntryDate)"/>
			</TD>
			</TR>
		</xsl:if>
	</xsl:if>
	</xsl:template>

</xsl:stylesheet>
