<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:param name="RegularHours"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="HolidaysProcessing.inc"/>
	<xsl:include href="ActivitiesProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
	<xsl:key name="task_day_key" match="//DAY" use="PLANENTRY/@TASKID"/>
	<xsl:template match="/">
		<xsl:value-of select="vb:SetRegularHours($RegularHours)"/>
		<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			{AllTasks}
			</xsl:if> - <xsl:value-of select="vb:GetCurrentDate()"/>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle"> 
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
			<xsl:value-of select="vb:GetParentNames(.)"/>
			<xsl:value-of select="@NAME"/>
			</xsl:for-each> 
			<xsl:if test="$AffectedCategory = 0">
			All tasks
			</xsl:if>
		</xsl:variable>
		<HTML>
			<HEAD>
				<TITLE>{Report}: {ProjectTimeSummaries} (<xsl:value-of select="$projectTitle"/>)</TITLE>
				<META NAME="Report" CONTENT="{ProjectTimeSummaries}"/>
				<STYLE ID="ReportStyle">
				<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<H2>{ProjectTimeSummaries}</H2>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="0">
						<tr>
						<td class="righttitle">{Employee}: </td>
						<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
						</tr>
						<tr>
						<td class="righttitle">{Category}: </td>
						<td class="underlined"><xsl:value-of select="$parentProjectTitle"/>&#160;</td>
						</tr>
						<tr>
						<td class="righttitle">{Date}: </td>
						<td class="underlined"><xsl:value-of select="vb:GetCurrentDate()"/></td>
						</tr>
					</table>
				</xsl:for-each>

				<xsl:choose>
				<xsl:when test="$AffectedCategory != 0">
				<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
					<xsl:apply-templates select=".//TASK"/>
				</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
				<xsl:for-each select="//TASK">
					<xsl:apply-templates select="."/>
				</xsl:for-each>
				</xsl:otherwise>
				</xsl:choose>

				<xsl:variable name="originalEstimatesCat" select="sum(.//TASK[@STATUS=2]/@ORIGINALESTIMATION)"/>
				<xsl:variable name="catPlanEntriesList" select="//DAY/PLANENTRY[@TASKID=//CATEGORY[@ID=$AffectedCategory]//TASK[@STATUS=2]/@ID]"/>
				<xsl:variable name="stageWorkingHours" select="vb:CalculateHours($catPlanEntriesList)"/>
				<xsl:variable name="plannedPlanEntriesList" select="//DAY/PLANENTRY[@TASKID=//CATEGORY[@ID=$AffectedCategory]//TASK[boolean(@ORIGINALESTIMATION)][@STATUS=2]/@ID]"/>
				<xsl:variable name="plannedWorkingHours" select="vb:CalculateHours($plannedPlanEntriesList)"/>
				<BR/>

				<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0">
				<TR>
					<TD class="summaryHead" COLSPAN="2">{Summaries}</TD>
				</TR>
				<TR>
					<TD class="summaryName">{StartedAt}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:FormatDate(vb:GetFirstEntryDateInCategory())"/>&#160;
					</TD>
				</TR>
				<TR>
					<TD class="summaryName">LastActivity:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:FormatDate(vb:GetLastEntryDateInCategory())"/>&#160;
					</TD>
				</TR>
				<TR>
					<TD class="summaryName">WorkingDays:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:GetWorkingDaysNumber()"/>
        (<xsl:value-of select="vb:GetWorkingDaysInHours($RegularHours)"/> {hours})</TD>
				</TR>
				<TR>
					<TD class="summaryName">{EffectiveProjectHours}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:FormatNumberEx(vb:GetAllWorkingHours())"/>
					</TD>
				</TR>
				<TR>
					<TD class="summaryName">{PresenceInTheProject}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:GetPresence()"/> %</TD>
				</TR>
				<TR>
					<TD class="summaryName">{EstimationError}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:GetEstimationError()"/> % 
		(<xsl:value-of select="vb:GetEffortErrorMin()"/> % - 
		<xsl:value-of select="vb:GetEffortErrorMax()"/> %)</TD>
				</TR>
				<TR>
					<TD class="summaryName">{TimeOverSpend}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of 
							select="vb:CalculateOverSpend($originalEstimatesCat, $stageWorkingHours)"/> %</TD>
				</TR>
				<TR>
					<TD class="summaryName">{TimeOverSpendFromUnplanned}:</TD>
					<TD class="freeTableCell">
						<xsl:value-of select="vb:CalculateOverSpendFromUnplanned($originalEstimatesCat, $stageWorkingHours, $plannedWorkingHours)"/> %</TD>
				</TR>
				</TABLE>
				
				<br/>
				<table border="0" cellpadding="2" cellspacing="0">
				<tr><td colspan="2">&#160; </td></tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				<tr><td colspan="2">&#160; </td></tr>
				<tr>
				<td class="signetureCell">{ManagerSignature}</td>
				<td class="signetureCell">{Date}</td>
				</tr>
				</table>
			</BODY>
		</HTML>
	</xsl:template>
	<xsl:template match="TASK">
		<xsl:variable name="id" select="@ID"/>
		<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
		<xsl:variable name="planEntriesDaysList" select="key('task_day_key', $id)"/>
		<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>
		<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
		<xsl:variable name="lastPlanEntryDate" select="vb:GetLastPlanEntryDate($planEntriesDaysList)"/>
		<xsl:variable name="firstPlanEntryDate" select="vb:GetFirstPlanEntryDate($planEntriesDaysList)"/>
		<xsl:variable name="tempPushDates" select="vb:PushPlanEntryDates($firstPlanEntryDate, $lastPlanEntryDate, string(@STATUS))"/>
		<xsl:variable name="tempPushHours" select="vb:PushHours($workingHours, js:ToDbl(string(@ESTIMATION)), string(@STATUS))"/>

		<xsl:value-of select="$tempPushHours"/>

	</xsl:template>
</xsl:stylesheet>
