<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:ms="urn:schemas-microsoft-com:xslt" xmlns:vb="urn:the-xml-files:xslt-vb" xmlns:js="urn:the-xml-files:xslt-js" version="1.0">
	<xsl:output method="html"/>
	<xsl:param name="AffectedCategory"/>
	<xsl:include href="WeekProcessing.inc"/>
	<xsl:include href="HolidaysProcessing.inc"/>
	<xsl:include href="Intending.inc"/>
	<xsl:include href="Common.inc"/>
	<xsl:include href="LocaleIndependent.inc"/>
	<xsl:include href="PlanEntryProcessing.inc"/>
	<xsl:include href="Subprojects.inc"/>
	<xsl:include href="ReportCSS.inc"/>
	<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
	<xsl:template match="/">
		<xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
		<xsl:value-of select="vb:SetReportingPeriod(vb:GetCurrentDate(), vb:GetCurrentDate())"/>
		<xsl:variable name="projectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
			All tasks
			</xsl:if>
		</xsl:variable>
		<xsl:variable name="parentProjectTitle">
			<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
				<xsl:value-of select="vb:GetParentNames(.)"/>
				<xsl:value-of select="@NAME"/>
			</xsl:for-each>
			<xsl:if test="$AffectedCategory = 0">
		All tasks
		</xsl:if>
		</xsl:variable>
		<HTML>
			<HEAD>
				<TITLE>{Report}: {FixedDateToDoTasks} {since} <xsl:value-of select="vb:GetCurrentDate()"/></TITLE>
				<META NAME="Report" CONTENT="{FixedDateToDoTasks}"/>
				<STYLE ID="ReportStyle">
					<xsl:value-of select="$css"/>
				</STYLE>
			</HEAD>
			<BODY>
				<H2>{FixedDateToDoTasks}</H2>
				<xsl:for-each select="//PROPERTIES">
					<table border="0" cellpadding="2" cellspacing="0">
						<tr>
							<td class="righttitle">{Employee}: </td>
							<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
						</tr>
						<tr>
							<td class="righttitle">{Category}: </td>
							<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
						</tr>
						<tr>
						<td class="righttitle">{StartDate}: </td>
						<td class="underlined"><xsl:value-of select="vb:GetCurrentDate()"/></td>
						</tr>
					</table>
				</xsl:for-each>
				<br/>
				<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
					<THEAD style="display: table-header-group">
						<TR>
							<TD class="leftHeadCell">{Date}</TD>
							<TD class="headCell" width="100%">{Task}</TD>
							<TD class="headCell">{Estimation}</TD>
						</TR>
					</THEAD>
					<TBODY>
						<xsl:call-template name="ShowDays">
						<xsl:with-param name="currentContext" select="/"/>
						</xsl:call-template>
					</TBODY>
				</TABLE>
				<BR/>
				<table border="0" cellpadding="2" cellspacing="0">
					<tr><td colspan="2">  </td></tr>
					<tr><td colspan="2">  </td></tr>
					<tr>
						<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
						<td class="signetureCell">{Date}</td>
					</tr>
					<tr><td colspan="2">  </td></tr>
					<tr>
						<td class="signetureCell">{ManagerSignature}</td>
						<td class="signetureCell">{Date}</td>
					</tr>
				</table>
			</BODY>
		</HTML>
	</xsl:template>
	
	<xsl:template name="ShowDays">
		<xsl:param name="currentContext"/>

		<xsl:value-of select="vb:ResetStart()"/>
		<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<!--<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">-->
		<xsl:if test="ms:node-set($currentContext)//CATEGORY[@ID=$AffectedCategory]//TASK[(@STATUS='0' or @STATUS='1') and vb:IsBiggerDate(string(@DEADLINE), vb:GetDaysIteratorString())]">
		
		<TR>
			<TD class="taskCell" colspan="3">
			<xsl:call-template name="HolidayColoring">
				<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
				<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
			</xsl:call-template>
			<xsl:value-of select="vb:ToWeekDayOnly(vb:GetDaysIteratorString())"/><BR/></TD>
		</TR>

		<xsl:choose>
			<xsl:when test="$AffectedCategory != 0">
				<xsl:for-each select="ms:node-set($currentContext)//CATEGORY[@ID=$AffectedCategory]//TASK[(@STATUS='0' or @STATUS='1') and vb:IsEqualDate(string(@DEADLINE), vb:GetDaysIteratorString())]">
					<xsl:sort select="@IMPORTANCE"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:for-each select="ms:node-set($currentContext)//TASK[(@STATUS='0' or @STATUS='1') and vb:IsEqualDate(string(@DEADLINE), vb:GetDaysIteratorString())]">
					<xsl:sort select="@IMPORTANCE"/>
					<xsl:apply-templates select="."/>
				</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>

		</xsl:if>
		<xsl:value-of select="vb:MoveNextDay()"/>
		</xsl:for-each>

	</xsl:template>
	
	<xsl:template match="TASK">
		<xsl:variable name="planEntriesList" select="key('task_key', @ID)"/>
		<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
		<TR>
			<TD class="taskCell" align="center"><xsl:value-of select="vb:FormatDate(string(@DEADLINE))"/></TD>
			<TD class="taskDescription"><xsl:value-of select="@NAME"/></TD>
			<TD class="taskDescription" align="center"><xsl:value-of select="vb:FormatNumberEx(js:ToDbl(string(@ESTIMATION)))"/></TD>
		</TR>
	</xsl:template>
	
	<xsl:template name="HolidayColoring">
		<xsl:param name="defaultColor"/>
		<xsl:param name="holidayColor"/>
		<xsl:attribute name="BGCOLOR">
			<xsl:choose>
				<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
			</xsl:choose>
		</xsl:attribute>
	</xsl:template>
</xsl:stylesheet>
