<?xml version='1.0'?>
<xsl:stylesheet 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:ms="urn:schemas-microsoft-com:xslt"
xmlns:vb="urn:the-xml-files:xslt-vb"
xmlns:js="urn:the-xml-files:xslt-js"
version="1.0">
<xsl:output method="html"/>
<xsl:param name="ReportingPeriodStart"/>
<xsl:param name="ReportingPeriodEnd"/>
<xsl:include href="WeekProcessing.inc"/>
<xsl:include href="PlanEntryProcessing.inc"/>
<xsl:include href="HolidaysProcessing.inc"/>
<xsl:include href="Common.inc"/>
<xsl:include href="ReportCSS.inc"/>

<xsl:key name="task_key" match="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY" use="@TASKID"/>

<xsl:template match="/">
  <xsl:value-of select="vb:PushHolidays(//HOLIDAYS/HOLIDAY/@DATE)"/>
  <xsl:value-of select="vb:SetReportingPeriod($ReportingPeriodStart, $ReportingPeriodEnd)"/>

<HTML>
<HEAD>
<TITLE>{Report}: {WeeklyTasksReview} (<xsl:value-of select="vb:FormatThisPeriod()"/>)</TITLE>
<META NAME="Report" CONTENT="{WeeklyTasksReview}"/>
<STYLE ID="ReportStyle">
<xsl:value-of select="$css"/>
</STYLE>
</HEAD>
<BODY>

<xsl:for-each select="//PROPERTIES">
<table border="0" cellpadding="2" cellspacing="2">
<tr><td colspan="2" class="company"><xsl:value-of select="@COMPANY"/></td></tr>
  <tr> 
    <td width="270" class="addr">
    <pre><xsl:value-of select="ADDRESS"/></pre></td>
    <td valign="top">
	<table width="100%" border="0" class="headingtable">
	<tr>
	<td class="righttitle">{EmployeeName}: </td>
	<td class="employee"><xsl:value-of select="@AUTHOR"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{ManagerName}: </td>
	<td class="underlined"><xsl:value-of select="@MANAGER"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	<tr>
	<td class="righttitle">{ReportingPeriod}: </td>
	<td class="underlined"><xsl:value-of select="vb:FormatThisPeriod()"/></td>
	</tr>
	<tr>
	<td colspan="2" class="emptyrow"></td>
	</tr>
	</table>
  </td>
  </tr>
  <tr><td colspan="2" class="doctitle">{WeeklyTasksReview}</td></tr>
</table>
</xsl:for-each>

<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0">
<THEAD style="display: table-header-group">
	<TR>
	<TD class="leftHeadCell">{Task}</TD>
	<xsl:value-of select="vb:ResetStart()"/>
	<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
			<TD class="headCell">
			<xsl:call-template name="HolidayColoring">
			<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
			<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
			</xsl:call-template>
			<xsl:value-of select="vb:ToWeekDayName(vb:GetDaysIteratorString())"/>
			</TD>
		</xsl:if>
		<xsl:value-of select="vb:MoveNextDay()"/>
	</xsl:for-each>
	<TD class="headCell">{Tot}</TD>
	</TR>
</THEAD>
<TBODY>
	<xsl:for-each select="//TASK">
		<xsl:sort select="@NAME"/>
		<xsl:apply-templates select="."/>
	</xsl:for-each>      

	<TR>
		<TD class="leftTotalCell">{DailyTotals}</TD>
		<xsl:call-template name="DailyTotals">
		<xsl:with-param name="currentContext" select="/"/>
		</xsl:call-template>

		<xsl:variable name="weeklyDaysList" 
		select="//DAY[vb:IsDateOfPeriod(string(@DATE))]/PLANENTRY"/>
		<xsl:variable name="weeklyWorkingHours" select="vb:CalculateHours($weeklyDaysList)"/>
		<TD class="totalCell"><xsl:value-of select="$weeklyWorkingHours"/></TD>
	</TR>
</TBODY>
</TABLE>

<br/>

<table border="0" cellpadding="2" cellspacing="0">
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
<tr><td colspan="2">&#160; </td></tr>
<tr><td colspan="2">&#160; </td></tr>
<tr>
<td class="signetureCell">{ManagerSignature}</td>
<td class="signetureCell">{Date}</td>
</tr>
</table>

</BODY>
</HTML>
</xsl:template>

<xsl:template match="TASK">
	<xsl:variable name="id" select="@ID"/>
	<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
	<xsl:variable name="nPlanEntries" select="count($planEntriesList)"/>
	<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
	<xsl:if test="$nPlanEntries>0">
        <TR>
          <TD class="taskCell">
          <xsl:value-of select="@NAME"/></TD>
          <xsl:call-template name="TaskHours">
          <xsl:with-param name="currentContext" select="/"/>
          <xsl:with-param name="id" select="$id"/>
          </xsl:call-template>
          
          <TD class="taskTotalCell"><xsl:value-of select="$workingHours"/></TD>
        </TR>
      </xsl:if>
</xsl:template>

<xsl:template name="TaskHours">
	<xsl:param name="currentContext"/>
	<xsl:param name="id"/>
	<xsl:value-of select="vb:ResetStart()"/>
	<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
		<xsl:for-each select="ms:node-set($currentContext)">
			<xsl:variable name="daysList"
			select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY[@TASKID=$id]"/>
			<xsl:variable name="dayTaskHours" select="vb:CalculateHoursWONuls($daysList)"/>
			<TD class="tableCell"><xsl:call-template name="HolidayColoring">
			<xsl:with-param name="defaultColor">#FFFFFF</xsl:with-param>
			<xsl:with-param name="holidayColor">#EEEEEE</xsl:with-param>
			</xsl:call-template>
			&#160;<xsl:value-of select="$dayTaskHours"/>
			</TD>
		</xsl:for-each>
		</xsl:if>
		<xsl:value-of select="vb:MoveNextDay()"/>
	</xsl:for-each>
</xsl:template>

<xsl:template name="DailyTotals">
	<xsl:param name="currentContext"/>
	<xsl:value-of select="vb:ResetStart()"/>
	<xsl:for-each select="ms:node-set($weekDaysList)/IT">
		<xsl:if test="vb:IsDateOfPeriod(vb:GetDaysIteratorString())">
		<xsl:for-each select="ms:node-set($currentContext)">
			<xsl:variable name="daysList"
			select="//DAY[vb:IsEqualNextDate(string(@DATE))]/PLANENTRY"/>
			<xsl:variable name="dayTaskHours" select="vb:CalculateHoursWONuls($daysList)"/>
			<TD class="totalCell">&#160;<xsl:value-of select="$dayTaskHours"/></TD>
		</xsl:for-each>
		<xsl:value-of select="vb:MoveNextDay()"/>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

<xsl:template name="HolidayColoring">
	<xsl:param name="defaultColor"/>
	<xsl:param name="holidayColor"/>
	<xsl:attribute name="BGCOLOR">
	<xsl:choose>
 		<xsl:when test="vb:IsHoliday(vb:GetDaysIteratorString())"><xsl:value-of select="$holidayColor"/></xsl:when>
 		<xsl:otherwise><xsl:value-of select="$defaultColor"/></xsl:otherwise>
 	</xsl:choose>
 	</xsl:attribute>
</xsl:template>

</xsl:stylesheet>