<?xml version='1.0'?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
xmlns:ms="urn:schemas-microsoft-com:xslt"
xmlns:vb="urn:the-xml-files:xslt-vb"
xmlns:js="urn:the-xml-files:xslt-js"
version="1.0">
<xsl:output method="html"/>
<xsl:param name="AffectedCategory"/>
<xsl:include href="Common.inc"/>
<xsl:include href="LocaleIndependent.inc"/>
<xsl:include href="PlanEntryProcessing.inc"/>
<xsl:include href="Subprojects.inc"/>
<xsl:include href="ReportCSS.inc"/>
<xsl:key name="task_key" match="//DAY/PLANENTRY" use="@TASKID"/>
  <xsl:template match="/">
  
  <xsl:variable name="projectTitle">
<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]">
<xsl:value-of select="@NAME"/>
</xsl:for-each>
<xsl:if test="$AffectedCategory = 0">
{AllTasks}
</xsl:if>
</xsl:variable>

<xsl:variable name="parentProjectTitle"> 
   <xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]"> 
      <xsl:value-of select="vb:GetParentNames(.)"/>
      <xsl:value-of select="@NAME"/>
   </xsl:for-each> 
   <xsl:if test="$AffectedCategory = 0">
    {AllTasks}
   </xsl:if>
</xsl:variable>

<HTML>
<HEAD>
<META NAME="Report" CONTENT="{WorkOnProjectTasks}"/>
<TITLE>{Report}: {Tasks} {of} <xsl:value-of select="$projectTitle"/>.</TITLE>
<STYLE ID="ReportStyle">
<xsl:value-of select="$css"/>
</STYLE>
</HEAD>
  <BODY>
<H2>{ProjectTasks}</H2>
<xsl:for-each select="//PROPERTIES">
	<table border="0" cellpadding="2" cellspacing="0">
		<tr>
		<td class="righttitle">{Employee}: </td>
		<td class="underlined"><xsl:value-of select="@AUTHOR"/></td>
		</tr>
		<tr>
		<td class="righttitle">{Category}: </td>
		<td class="underlined"><xsl:value-of select="$parentProjectTitle"/></td>
		</tr>
		<tr>
		<td class="righttitle">{Date}: </td>
		<td class="underlined"><xsl:value-of select="vb:GetCurrentDate()"/></td>
		</tr>
	</table>
</xsl:for-each>

<br/>

<TABLE BORDER="0" CELLPADDING="2" CELLSPACING="0" WIDTH="100%">
    <THEAD style="display: table-header-group"> 
      <TR>
        <TD class="leftHeadCell">{N}</TD>
        <TD class="headCell">{Name}</TD>
        <TD class="headCell">{Description}</TD>
        <TD class="headCell">{Priority}</TD>
        <TD class="headCell">{Estimation} ({hours})</TD>
        <TD class="headCell">{Spent} ({hours})</TD>
        <TD class="headCell">{Status}</TD>
        <TD class="headCell">{Deadline}</TD>
      </TR>
    </THEAD>
    <TBODY>
	<xsl:choose>
	<xsl:when test="$AffectedCategory != 0">
	<xsl:for-each select="//CATEGORY[@ID=$AffectedCategory]//TASK">
	<xsl:sort select="@STATUS" order="descending"/>
	<xsl:sort select="@IMPORTANCE"/>
	<xsl:sort select="@DEADLINE"/>
	<xsl:sort select="@NAME"/>
	<xsl:apply-templates select="."/>
	</xsl:for-each>
	</xsl:when>
	<xsl:otherwise>
	<xsl:for-each select="//TASK">
	<xsl:sort select="@STATUS" order="descending"/>
	<xsl:sort select="@IMPORTANCE"/>
	<xsl:sort select="@DEADLINE"/>
	<xsl:sort select="@NAME"/>
	<xsl:apply-templates select="."/>
	</xsl:for-each>
	</xsl:otherwise>
	</xsl:choose>
    </TBODY>
    </TABLE>
	<BR/>
	<table border="0" cellpadding="2" cellspacing="0">
	<tr><td colspan="2">&#160; </td></tr>
	<tr><td colspan="2">&#160; </td></tr>
	<tr>
	<td class="signetureCell" style="width: 300">{EmployeeSignature}</td>
	<td class="signetureCell">{Date}</td>
	</tr>
	<tr><td colspan="2">&#160; </td></tr>
	<tr>
	<td class="signetureCell">{ManagerSignature}</td>
	<td class="signetureCell">{Date}</td>
	</tr>
	</table>
  </BODY>
</HTML>
</xsl:template>

<xsl:template match="TASK">
	<xsl:variable name="id" select="@ID"/>
	<xsl:variable name="planEntriesList" select="key('task_key', $id)"/>
	<xsl:variable name="workingHours" select="vb:CalculateHours($planEntriesList)"/>
	<TR>
	<TD class="taskCell"><xsl:value-of select="vb:NextNumber(@ID)"/></TD>
	<TD class="taskDescription"><xsl:value-of select="@NAME"/></TD>
	<TD class="taskDescription">
<xsl:variable name="taskDescription" select="vb:RestrictLength(string(DESCRIPTION), 110)"/>
<xsl:if test="string-length($taskDescription)&gt;0">
	<xsl:value-of select="$taskDescription"/><BR/>
</xsl:if>
<xsl:if test="string-length($taskDescription)=0">
	&#160;
</xsl:if>
<xsl:call-template name="PlanDescriptions"><xsl:with-param name="taskId" select="@ID"/></xsl:call-template>
	</TD>
	<TD class="freeTableCell"><xsl:value-of select="vb:GetImportanceString(@IMPORTANCE)"/></TD>
	<TD class="freeTableCell"><xsl:value-of select="vb:FormatNumberEx(js:ToDbl(string(@ESTIMATION)))"/></TD>
	<TD class="freeTableCell"><xsl:value-of select="$workingHours"/></TD>
	<TD class="freeTableCell"><xsl:value-of select="vb:GetStatusString(@STATUS)"/></TD>
	<TD class="freeTableCell"><xsl:value-of select="vb:FormatDate(string(@DEADLINE))"/></TD>
	</TR>
</xsl:template>

<xsl:template name="PlanDescriptions">
	<xsl:param name="taskId"/>
	<xsl:for-each select="//DAILY/DAY/PLANENTRY[@TASKID=$taskId]">
		<xsl:variable name="planDescription" select="vb:RestrictLength(string(DESCRIPTION), 110)"/>
		<xsl:if test="string-length($planDescription)&gt;0">
			<xsl:value-of select="$planDescription"/><BR/>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>